// src/index.ts
import { ExpressiveCodeTheme, InlineStyleAnnotation } from "@expressive-code/core";

// src/cache.ts
import { getHighlighter } from "shiki";
var highlighterPromise;
async function getCachedHighlighter({ theme }) {
  if (highlighterPromise === void 0) {
    highlighterPromise = getHighlighter({ theme });
  }
  const highlighter = await highlighterPromise;
  if (!highlighter.getLoadedThemes().includes(theme.name)) {
    await highlighter.loadTheme(theme);
  }
  return highlighter;
}

// src/index.ts
import { BUNDLED_THEMES, loadTheme, FontStyle } from "shiki";
async function loadShikiTheme(bundledThemeName) {
  const shikiTheme = await loadTheme(BUNDLED_THEMES.includes(bundledThemeName) ? `themes/${bundledThemeName}.json` : bundledThemeName);
  const shikiThemeWithoutType = { ...shikiTheme };
  delete shikiThemeWithoutType.type;
  return new ExpressiveCodeTheme(shikiThemeWithoutType);
}
function pluginShiki() {
  return {
    name: "Shiki",
    hooks: {
      performSyntaxAnalysis: async ({ codeBlock, theme }) => {
        const highlighter = await getCachedHighlighter({ theme });
        const codeLines = codeBlock.getLines();
        let code = codeBlock.code;
        if (isTerminalLanguage(codeBlock.language)) {
          code = code.replace(/<([^>]*[^>\s])>/g, "X$1X");
        }
        const tokenLines = highlighter.codeToThemedTokens(code, codeBlock.language, theme.name, { includeExplanation: false });
        tokenLines.forEach((line, lineIndex) => {
          let charIndex = 0;
          line.forEach((token) => {
            const tokenLength = token.content.length;
            const tokenEndIndex = charIndex + tokenLength;
            const fontStyle = token.fontStyle || FontStyle.None;
            codeLines[lineIndex].addAnnotation(
              new InlineStyleAnnotation({
                color: token.color || theme.fg,
                italic: (fontStyle & FontStyle.Italic) === FontStyle.Italic,
                bold: (fontStyle & FontStyle.Bold) === FontStyle.Bold,
                underline: (fontStyle & FontStyle.Underline) === FontStyle.Underline,
                inlineRange: {
                  columnStart: charIndex,
                  columnEnd: tokenEndIndex
                }
              })
            );
            charIndex = tokenEndIndex;
          });
        });
      }
    }
  };
}
function isTerminalLanguage(language) {
  return ["shellscript", "shell", "bash", "sh", "zsh"].includes(language);
}
export {
  loadShikiTheme,
  pluginShiki
};
//# sourceMappingURL=index.js.map